==> zio-aws-memorydb_3-5.17.104.3-sources.jar: zio/aws/memorydb/model/DeleteUserResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DeleteUserResponse(
    user: Option[zio.aws.memorydb.model.User] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DeleteUserResponse = {
    import DeleteUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
      .builder()
      .optionallyWith(user.map(value => value.buildAwsValue()))(_.user)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.DeleteUserResponse.ReadOnly =
    zio.aws.memorydb.model.DeleteUserResponse.wrap(buildAwsValue())
}
object DeleteUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DeleteUserResponse =
      zio.aws.memorydb.model
        .DeleteUserResponse(user.map(value => value.asEditable))
    def user: Option[zio.aws.memorydb.model.User.ReadOnly]
    def getUser: ZIO[Any, AwsError, zio.aws.memorydb.model.User.ReadOnly] =
      AwsError.unwrapOptionField("user", user)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
  ) extends zio.aws.memorydb.model.DeleteUserResponse.ReadOnly {
    override val user: Option[zio.aws.memorydb.model.User.ReadOnly] = scala
      .Option(impl.user())
      .map(value => zio.aws.memorydb.model.User.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
  ): zio.aws.memorydb.model.DeleteUserResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-memorydb_3-6.20.103.2-sources.jar: zio/aws/memorydb/model/DeleteUserResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteUserResponse(
    user: Optional[zio.aws.memorydb.model.User] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DeleteUserResponse = {
    import DeleteUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
      .builder()
      .optionallyWith(user.map(value => value.buildAwsValue()))(_.user)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.DeleteUserResponse.ReadOnly =
    zio.aws.memorydb.model.DeleteUserResponse.wrap(buildAwsValue())
}
object DeleteUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DeleteUserResponse =
      zio.aws.memorydb.model
        .DeleteUserResponse(user.map(value => value.asEditable))
    def user: Optional[zio.aws.memorydb.model.User.ReadOnly]
    def getUser: ZIO[Any, AwsError, zio.aws.memorydb.model.User.ReadOnly] =
      AwsError.unwrapOptionField("user", user)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
  ) extends zio.aws.memorydb.model.DeleteUserResponse.ReadOnly {
    override val user: Optional[zio.aws.memorydb.model.User.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.user())
        .map(value => zio.aws.memorydb.model.User.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteUserResponse
  ): zio.aws.memorydb.model.DeleteUserResponse.ReadOnly = new Wrapper(impl)
}
